@@ -7,7 +7,7 @@ import time as builtin_time
 import numpy as np
 import datetime
 
-
+from .path import *
 
 class Time():
     
@@ -336,7 +336,9 @@ def newpage(color_name="white", opacity=100,
             if opacity == 100:
                 try:
                     screen.fill(color(color_name))
+                    #print('success')
                 except:
+     
                     print("NEUROPSYDIA ERROR: newpage(): wrong argument")
                     
             else:
@@ -372,6 +374,7 @@ def newpage(color_name="white", opacity=100,
             screen.fill(color(original_color_name))
 
 
+    
 def refresh():
     
     """
@@ -397,8 +400,9 @@ def refresh():
 
     - pygame
     """
-    
+
     pygame.display.flip()
+    
 
 keys = {
 "normal":
